@@ -251,7 +251,7 @@
 #define INSTALL_SCRIPTDIR "/usr/local/mysql/bin"
 #define INSTALL_MYSQLDATADIR "/usr/local/mysql/data"
 #define INSTALL_MYSQLKEYRINGDIR "/usr/local/mysql/keyring"
-#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.12-5/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.12-5/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.12-5/plugin/scalability_metrics/tests"
+#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.13-6/plugin/scalability_metrics/tests;/build/percona-server/src/percona-server-5.7.13-6/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.13-6/plugin/audit_log/tests"
 #define INSTALL_INFODIR "/usr/local/mysql/share/mysql/docs"
 #define INSTALL_MYSQLTESTDIR "/usr/local/mysql/mysql-test"
 #define INSTALL_DOCREADMEDIR "/usr/local/mysql/share/mysql"
@@ -386,15 +386,15 @@
 #define DOT_FRM_VERSION 6
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 7
-#define MYSQL_VERSION_PATCH 12
-#define MYSQL_VERSION_EXTRA "-5"
+#define MYSQL_VERSION_PATCH 13
+#define MYSQL_VERSION_EXTRA "-6"
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.7.12-5"
+#define PACKAGE_STRING "MySQL Server 5.7.13-6"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.7.12-5"
-#define VERSION "5.7.12-5"
+#define PACKAGE_VERSION "5.7.13-6"
+#define VERSION "5.7.13-6"
 #define PROTOCOL_VERSION 10
 
 /*
